@@ -20,7 +20,6 @@ Query and related classes
 """
 
 #Current query class only works for indexable elements
-#for concepts ands relations, other operators are required: ELEMENT HASA CONCEPT1 OR ELEMENT ISA CONCEPT4 OR ELEMENT PROPERTY CONCEPT5
 
 __author__ = "Nestor Arocha"
 __copyright__ = "Copyright 2008-2013, Nestor Arocha"
@@ -49,14 +48,12 @@ class QueryPartial(QueryTerm):
     def __str__(self):
         return "<" + str(self.left) + "=~" + str(self.right) + ">"
 
-
 class QueryInclusion(QueryTerm):
     """ looks for an element within a list """
-    pass
-
-class QueryGreaterThan(QueryTerm):
-    """associated with > symbol """
-    pass
+    def __init__(self, left, right, dict_member = "values"):
+        """dict_member could be keys or values"""
+        QueryTerm.__init__(self, left, right)
+        self.dict_member = dict_member
 
 class BinaryOperator(QueryElement):
     def __init__(self, element1, element2):
