@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-#Copyright (C) 2008-2011 Néstor Arocha Rodríguez
+#Copyright (C) 2008-2013 Nestor Arocha
 
 def matchFun(myinput):
     strnumber = str(myinput)
@@ -9,7 +9,7 @@ def matchFun(myinput):
         number = int(strnumber)
     except ValueError:
         return False
-    if number > 0 and number < 32:
+    if 0 < number < 32:
         return True
     return False
 
